"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageBuilder = void 0;
const Utils_1 = require("../Utils");
class MessageBuilder {
	static build(builderFn) {
		let entities = [];
		let component = new MessageBuilderComponent();
		let text = builderFn(component);
		let componentStartBorder = "[" + component.id + "|id";
		for (
			let index = text.indexOf(componentStartBorder);
			index !== -1;
			index = text.indexOf(componentStartBorder)
		) {
			let componentEndBorderIndex = text.indexOf("]", index);
			let entityId = text.slice(
				index + componentStartBorder.length,
				componentEndBorderIndex
			);
			let entity = component.getEntityById(entityId);
			for (let type of entity.types)
				entities.push(
					Object.assign(
						{
							type: type.type,
							length: entity.content.length,
							offset: index,
						},
						Utils_1.ObjectUtils.filterObjectByKey(
							type,
							p => p !== "type"
						)
					)
				);
			text =
				text.slice(0, index) +
				entity.content +
				text.slice(componentEndBorderIndex + 1);
		}
		return {
			text,
			entities,
		};
	}
	static concat(...formattedMessages) {
		return formattedMessages.reduce(
			(acc, msg) => {
				var _a, _b, _c;
				msg.entities =
					(_b =
						(_a =
							msg === null || msg === void 0
								? void 0
								: msg.entities) === null || _a === void 0
							? void 0
							: _a.map(e => {
									e.offset += acc.text.length;
									return e;
							  })) !== null && _b !== void 0
						? _b
						: [];
				msg.entities = (
					(_c =
						acc === null || acc === void 0
							? void 0
							: acc.entities) !== null && _c !== void 0
						? _c
						: []
				).concat(msg.entities);
				msg.text = acc.text + msg.text;
				return msg;
			},
			{ text: "" }
		);
	}
}
exports.MessageBuilder = MessageBuilder;
class MessageBuilderComponent {
	constructor() {
		this.id = `MessageBuilder${Math.random()}`;
		this.entities = {};
	}
	getEntityById(entityId) {
		return this.entities[entityId];
	}
	mention(content) {
		return this.add(content, {
			type: "mention",
		});
	}
	hashtag(content) {
		return this.add(content, {
			type: "hashtag",
		});
	}
	cashtag(content) {
		return this.add(content, {
			type: "cashtag",
		});
	}
	command(content) {
		return this.add(content, {
			type: "bot_command",
		});
	}
	url(content) {
		return this.add(content, {
			type: "url",
		});
	}
	email(content) {
		return this.add(content, {
			type: "email",
		});
	}
	phone(content) {
		return this.add(content, {
			type: "phone_number",
		});
	}
	bold(content) {
		return this.add(content, {
			type: "bold",
		});
	}
	italic(content) {
		return this.add(content, {
			type: "italic",
		});
	}
	underline(content) {
		return this.add(content, {
			type: "underline",
		});
	}
	strikethrough(content) {
		return this.add(content, {
			type: "strikethrough",
		});
	}
	spoiler(content) {
		return this.add(content, {
			type: "spoiler",
		});
	}
	code(content) {
		return this.add(content, {
			type: "code",
		});
	}
	pre(content, language) {
		return this.add(content, {
			type: "pre",
			language,
		});
	}
	textLink(content, url) {
		return this.add(content, {
			type: "text_link",
			url,
		});
	}
	textMention(content, user) {
		return this.add(content, {
			type: "text_mention",
			user: `tg://user?id=${user.id}`,
		});
	}
	emoji(content, emoji) {
		return this.add(content, {
			type: "custom_emoji",
			custom_emoji: emoji,
		});
	}
	add(content, entity) {
		if (content.includes(this.id)) {
			let { 1: id } = content.match(/id([^\]]+)/);
			this.entities[id].types.push(entity);
			return content;
		}
		let id = `${Math.random()}${content.length}`;
		this.entities[id] = {
			content: content,
			types: [entity],
		};
		return `[${this.id}|id${id}]`;
	}
}
