/// <reference types="node" />
/// <reference types="node" />
import { Api } from "../Api";
import { ReadStream } from "fs";
import { Message } from "../models/Message";
import { ChatContext } from "./ChatContext";
import { IMessage } from "../types/IMessage";
import { IUpdateResult } from "../types/IUpdate";
import { Attachment } from "../models/attachments";
import { ICaptionEditParams, ITextEditParams } from "../types/params/IEditParams";
import { AttachmentType, IAttachmentSendParams, IBaseSendParams } from "../types/params/ISendParams";
import { IAttachment, IAudioAttachment, IDocumentAttachment, IPhotoAttachment, IVideoAttachment, IVoiceAttachment } from "../types/IAttachment";
declare type AttachmentSource<TAttachment extends IAttachment> = string | Buffer | ReadStream | Attachment<TAttachment>;
declare type SendMessageParams = string | ({
    text: string;
} & Partial<IBaseSendParams>);
export declare class MessageContext extends Message {
    private readonly api;
    match: string[];
    chat: ChatContext;
    constructor(api: Api, source: IMessage);
    pin(id?: number, disableNotification?: boolean): Promise<boolean>;
    unpin(id?: number): Promise<boolean>;
    unpinAll(): Promise<boolean>;
    editText(text?: string, params?: ITextEditParams | ICaptionEditParams): Promise<IUpdateResult>;
    delete(msgId?: number): Promise<boolean>;
    replyMessage(params: SendMessageParams): Promise<Message>;
    sendMessage(params: SendMessageParams): Promise<Message>;
    readonly replyVoice: (source: AttachmentSource<IVoiceAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyVideo: (source: AttachmentSource<IVideoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyAudio: (source: AttachmentSource<IAudioAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyPhoto: (source: AttachmentSource<IPhotoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly replyDocument: (source: AttachmentSource<IDocumentAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendVoice: (source: AttachmentSource<IVoiceAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendVideo: (source: AttachmentSource<IVideoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendAudio: (source: AttachmentSource<IAudioAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendPhoto: (source: AttachmentSource<IPhotoAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    readonly sendDocument: (source: AttachmentSource<IDocumentAttachment>, params: Partial<IAttachmentSendParams> | string) => Promise<Message>;
    private sendAttachWithCaption;
    attach<TAttachmentType extends AttachmentType>(type: TAttachmentType, source: AttachmentSource<any>, params?: Partial<IAttachmentSendParams>): Promise<Message>;
    private reply;
    private send;
    private execute;
}
export {};
